//
//  ChatView.swift
//  Chat
//
//  Created by Sergey Tarasov on 24.07.2022.
//

import SwiftUI
import XMPPFramework
import XMPPFrameworkSwift

extension CGFloat {
    static let sidePadding: CGFloat = 14
}

struct ChatView: View {
    @StateObject var store: ChatStore

    var body: some View {
        VStack(alignment: .center, spacing: 0) {
			ChatMessageListView(messages: store.messages)
            Divider()
			MessageTextField(message: $store.messageText, action: store.sendMessage)
        }
        .navigationTitle(store.room.roomJID.user ?? "Room")
        .navigationBarTitleDisplayMode(.inline)
        .toolbar {
            ToolbarItem(placement: .navigationBarTrailing) {
                Button {
                    store.fetchMessages()
                } label: {
                    Image(systemName: "arrow.counterclockwise")
                }
            }
        }
    }
}

struct ChatView_Previews: PreviewProvider {
    static var store: ChatStore = ChatStore(with: "jid")

    static var previews: some View {
        Group {
			NavigationView {
				ChatView(store: store)
			}
        }
    }
}
